//
// FT857 housing project
// Part: Cover bottom part-2
// (c) 2018 Jan Uhrin, OM2JU
//
// Using external libraries; original autor comments included
//----------------------------------------------------------------------------------
//
// (c) 2011 Christopher "ScribbleJ" Jansen
// 
// bend() module - creates a cube with a U or L shaped bend of the specified
// radius.

// d1 = length of first cube segment
// d2 = length of second cube segment
// r = (inner) radius of bend
// w = width of cube
// a = angle of bend.  0 = U, 180 = ---
// h = height of cube

$fn=64; //60;

//--------------------------------------------------------------------------------------
module bend(d1=10,d2=10,r=10,w=5,a=0,h=10)
{
  huge = r*w+6;
  difference()
  {
    cylinder(r=r+w, h=h);

    translate([0,0,-0.5]) 
    {
      cylinder(r=r, h=h+1);
      translate([0,r-huge,0]) cube([huge, huge, h+1]);
      rotate([0,0,-a]) translate([0,-r,0]) cube([huge, huge, h+1]);
    }
  }

  translate([0,r,0]) cube([d1, w, h]);
  rotate([0,0,-a]) translate([0,-(r+w),0]) cube([d2, w, h]);
}

// Rounded primitives for openscad
// (c) 2013 Wouter Robers 

// Syntax example for a rounded block
//translate([-15,0,10]) rcube([20,20,20],2);

// Syntax example for a rounded cylinder
//translate([15,0,10]) rcylinder(r1=15,r2=10,h=20,b=2);

module rcube(Size=[20,20,20],b=2)
{hull(){for(x=[-(Size[0]/2-b),(Size[0]/2-b)]){for(y=[-(Size[1]/2-b),(Size[1]/2-b)]){for(z=[-(Size[2]/2-b),(Size[2]/2-b)]){ translate([x,y,z]) sphere(b);}}}}}

//-----------------------------------------------------------------------------------

$len = 194;
$wid = 150.5+0.6;;
$h   = 17+2.5;
$round = 6;
$thick = 1.4;

$len = 194;
$h   = 21.5-3.5;

$offset_x = ($len/2);
$offset_y = $wid/2;


rotate([0,0,90]) {

// Side fixing
for (yy =[-75:75:75]) {    
difference() {
translate([yy,$offset_y+7.5,25]) rcube(Size = [10,2,8], b = 0.9);
translate([yy,$offset_y+7.5-1.1,25+4.0]) cube(size = [10,2,8], center = true);
}
}

for (yy =[-75:75:75]) {    
difference() {
translate([yy,-$offset_y+4.5,25]) rcube(Size = [10,2,8], b = 0.9);
translate([yy,-$offset_y+4.5+1.1,25+4.0]) cube(size = [10,2,8], center = true);
}
}


difference () {
union () {
translate([$offset_x,$offset_y,$round+$thick])
  rotate([0,-90,0])
    bend(d1=$h, d2=$wid/1.5, r=$round, w=$thick, a=90, h=$len);


translate([$offset_x-$len,$offset_y-$wid+2*$round,$round+$thick])
  rotate([180,-90,0])
    bend(d1=$h, d2=$wid/1.5, r=$round, w=$thick, a=90, h=$len);
}


// Vyrez stvorec
translate([-21, -$wid/2+14, -5]) linear_extrude(height = 10) square([104,$wid-16]);
// Licho
translate([-62, 6, -5]) linear_extrude(height = 10) polygon(points=[[0,-66/2],[0,66/2],
		[42,133/2],[42,-133/2]]);




// Front side holes
for (yy =[0:5:$wid/2-10]) {
translate([-$offset_x+3,yy+5,0])  cylinder(h=10, r1=1.5, r2=1.5, center=true);
translate([-$offset_x+3,-yy+5,0]) cylinder(h=10, r1=1.5, r2=1.5, center=true);
//
translate([-$offset_x+7,yy+7,0])  cylinder(h=10, r1=1.5, r2=1.5, center=true);
translate([-$offset_x+7,-yy+7,0]) cylinder(h=10, r1=1.5, r2=1.5, center=true);
}

// Two holes = top front
translate([-$offset_x+19+5.0,26+5,0])  cylinder(h=5, r1=8.0, r2=0.2, center=true);
translate([-$offset_x+19+5.0,-26+5,0]) cylinder(h=5, r1=8.0, r2=0.2, center=true);
// One hole incenter back
translate([-$offset_x+$len-2.8-1.5, 5-2,0]) cylinder(h=5, r1=6.0, r2=0.1, center=true);
//translate([-$offset_x+$len-2.5, 0,0]) cylinder(h=5, r1=6.0, r2=0.1, center=true);
//translate([-$offset_x+$len-2.5, 10,0]) cylinder(h=5, r1=6.0, r2=0.1, center=true);


// side holes, conical
rotate([90,0,0]) {
translate([-$offset_x+34,22.2,$offset_y-4.6]) cylinder(h=5, r1=0.1, r2=6.0, center=true);
translate([-$offset_x+34+118.6,22.2,$offset_y-4.6]) cylinder(h=5, r1=0.1, r2=6.0, center=true);

translate([-$offset_x+34+118.6,22.2,-$offset_y-7.4]) cylinder(h=5, r1=6.0, r2=0.1, center=true);

translate([-$offset_x+34,22.2,-$offset_y-7.4]) cylinder(h=5, r1=6.0, r2=0.1, center=true);
}


} // difference


} // rotate



