//
// FT857 housing project
// Part: Cover top
// (c) 2018 Jan Uhrin, OM2JU
//
// Using external libraries; original autor comments included
//----------------------------------------------------------------------------------
//
// (c) 2011 Christopher "ScribbleJ" Jansen
// 
// bend() module - creates a cube with a U or L shaped bend of the specified
// radius.

// d1 = length of first cube segment
// d2 = length of second cube segment
// r = (inner) radius of bend
// w = width of cube
// a = angle of bend.  0 = U, 180 = ---
// h = height of cube

$fn=32; //64;

//--------------------------------------------------------------------------------------
module bend(d1=10,d2=10,r=10,w=5,a=0,h=10)
{
  huge = r*w+6;
  difference()
  {
    cylinder(r=r+w, h=h);

    translate([0,0,-0.5]) 
    {
      cylinder(r=r, h=h+1);
      translate([0,r-huge,0]) cube([huge, huge, h+1]);
      rotate([0,0,-a]) translate([0,-r,0]) cube([huge, huge, h+1]);
    }
  }

  translate([0,r,0]) cube([d1, w, h]);
  rotate([0,0,-a]) translate([0,-(r+w),0]) cube([d2, w, h]);
}

//-----------------------------------------------------------------------------------

$len = 193;
$wid = 150.5+0.5+0.4;
$h   = 17+2.5;
$round = 6;
$thick = 1.4;

$len = 195;
$h   = 5+2.5+5;


$offset_x = ($len/2);
$offset_y = $wid/2;


rotate([0,0,90]) {



difference () {
union () {
  translate([10, -$wid/2+9, 1])  linear_extrude(height = 2.6) square([4,$wid-6]);
  translate([-58, -$wid/2+9, 1]) linear_extrude(height = 2.6) square([4,$wid-6]);
  translate([70, -$wid/2+9, 1])  linear_extrude(height = 2.6) square([4,$wid-6]);
}
rotate([0,90,0]) translate([-1.8,0, -$offset_x/3])  cylinder(h=120, r1=1, r2=1, center=true);
rotate([0,90,0]) translate([-1.8,-30, -$offset_x/3]) cylinder(h=120, r1=1, r2=1, center=true);
rotate([0,90,0]) translate([-1.8,-60,-$offset_x/3]) cylinder(h=120, r1=1, r2=1, center=true);
}

difference () {
union () {
translate([$offset_x,$offset_y,$round+$thick])
  rotate([0,-90,0])
    bend(d1=$h, d2=$wid/1.5, r=$round, w=$thick, a=90, h=$len);


translate([$offset_x-$len,$offset_y-$wid+2*$round,$round+$thick])
  rotate([180,-90,0])
    bend(d1=$h, d2=$wid/1.5, r=$round, w=$thick, a=90, h=$len);
}

// Front side holes
for (yy =[0:5:$wid/2-10]) {
translate([-$offset_x+3,yy+5,0])  cylinder(h=10, r1=1.6, r2=1.6, center=true);
translate([-$offset_x+3,-yy+5,0]) cylinder(h=10, r1=1.6, r2=1.6, center=true);
//
translate([-$offset_x+7,yy+7,0])  cylinder(h=10, r1=1.6, r2=1.6, center=true);
translate([-$offset_x+7,-yy+7,0]) cylinder(h=10, r1=1.6, r2=1.6, center=true);
}

// Two holes = top front
translate([-$offset_x+19+5.0,26+5,0])  cylinder(h=5, r1=5.5, r2=0.3, center=true);
translate([-$offset_x+19+5.0,-26+5,0]) cylinder(h=5, r1=5.5, r2=0.3, center=true);
// One hole incenter back
translate([-$offset_x+$len-4.0, 5,0]) cylinder(h=5, r1=5.5, r2=0.3, center=true);

// Two holes = left side + right side for keyer fixing (left hand or right hand)
translate([-$offset_x+19+18.0,26+7,0])  cylinder(h=5, r1=1.5, r2=1.5, center=true);
translate([-$offset_x+19+18.0,-26+3,0])  cylinder(h=5, r1=1.5, r2=1.5, center=true);


// Loudspeaker holes
for (xx =[0:5:40]) {
for (yy =[0:5:40]) {
translate([-$offset_x+55+xx,-44+yy,0]) cylinder(h=10, r1=1.6, r2=1.6, center=true);
}
}


// Text
rotate([180,0,0]) {
translate([$offset_x-15,$offset_y-28,0.0]) linear_extrude (height=1.8, center = true) text("S", size=12, font="Courier:style=Bold");
translate([$offset_x-15,$offset_y-42,0.0]) linear_extrude (height=1.8, center = true) text("K", size=12, font="Courier:style=Bold");

translate([$offset_x-15,2,0.0]) linear_extrude (height=1.8, center = true) text("D", size=12, font="Courier:style=Bold");
translate([$offset_x-15,-20,0.0]) linear_extrude (height=1.8, center = true) text("C", size=12, font="Courier:style=Bold");


}

} // difference

rotate([0,0,-90]) {
translate([-20,40,$thick]) linear_extrude (height=1.0, center = true) text("design", size=7, font="Courier:style=Bold");

translate([-20,27,$thick]) linear_extrude (height=1.0, center = true) text("OM2JU.com", size=9, font="Courier:style=Bold");
}

} // rotate

